require 'minitest/unit'
require 'appscreens'

class ClientTest < Minitest::Test

  def setup
    @client = Appscreens::Client.new
    @app_id = "333903271"
  end

  def teardown
    system("rm -rf /tmp/appscreens")
  end

  def test_can_lookup_a_given_app_id
    app = @client.lookup @app_id
    assert_instance_of(Hash, app, "App should be instance of Hash")
  end

  def test_app_should_have_screenshots_key
    app = @client.lookup @app_id
    screenshots = app[Appscreens::APP_SCREENSHOTS_KEY]
    assert(screenshots.length > 0, "Screenshots array should contain screenshots")
  end

  def test_download_screenshots_to_filesystem
    system("rm -rf /tmp/appscreens")

    path = "/tmp/appscreens"
    FileUtils::mkdir_p(path)
    app = @client.lookup @app_id
    @client.download_screenshots(app: app, icon: true, destination: path)

    expected_file_count = app[Appscreens::APP_SCREENSHOTS_KEY].length + 1
    file_count = Dir.glob(File.join(path, '**', '*')).select { |file| File.file?(file) }.count
    assert_equal(expected_file_count, file_count, "Expected #{expected_file_count} files. There was #{file_count}")
  end

end